==> ikapi-3.1.29.tgz: package/src/BaseEvent/IKProcess.js <==
//
import IKGlobals from '../IKGlobals';
import Utils  from "../API/IKUtils";
//Database
import IKDBDDB from "../Database/DDB/IKDB";
import IKDBPSQL from "../Database/PSQL/IKDB";
//Cache
import IKCacheRedis from '../Cache/Redis/IKRedis';
//Comps
import IKLogger from "../Logger/IKLogger";
import IKValidation from '../Validation/IKValidation';
import IKPublisher from '../Publisher/IKPublisher';
import IKExecutionTracker from '../Tracker/IKExecutionTracker';
//
export default class IKProcess {
  constructor(config, interval) {
    this._config = config;
    this.allowExecutionIdentification = false;
    this.interval = interval;
    this.logger = new IKLogger(config.logger, Utils.logLevel());
    this.publisher = new IKPublisher(config.publisher);
    this.validator = new IKValidation(config.validation);
    this.db = this._getDBDriver();
    this.cache = this._getCacheDriver();
    if (config.resourcesTracker) this.tracker = new IKExecutionTracker(config.resourcesTracker, null, this.db);
  }

  //Main interface
  async execute(executionFunc) {
    this.logger.debug("Starting main process code");
    //Tracker
    if (this.allowExecutionIdentification && this.tracker) this.tracker.resetExecutionTrace();
    //Connect DB
    if (this.db) await this.db.connect();
    //Program loop
    setInterval( async () => {
      await this._execute(executionFunc);
    }, this.interval);
    //Tracker
    if (this.allowExecutionIdentification && this.tracker) await this.tracker.trackExecAndDrain(true);
  }
  //Executions
  async _execute(executionFunc) {
    let executionFailed = true; //failled til we say no!
    //safe execution handler
    try { 
      //start DB transaction
      if (this.db) await this.db.beginTransaction();
      //Execute
      await executionFunc(this);
      //Commit DB
      if (this.db) await this.db.commit();
      //Tracker
      if (this.tracker) await this.tracker.quickDrain();
      //
      executionFailed = false;
    } catch (e) { /*EXECUTION FAIL*/
      this.logger.error('Exception when executing main request code. Rolling back DB!');
      this.logger.exception(e);
      //Rollback DB
      if (this.db) await this.db.rollback();
    } return executionFailed;
  }
  /* DB drivers support */
  _getDBDriver() {
    if (this._config.database) {
      if (this._config.database.type == IKGlobals.DBDrivers.PSQL) return new IKDBPSQL(this._config.database, this);
      else if (Object.keys(this._config.database).length > 0) return new IKDBDDB(this._config.database, this);
    } return null;
  }
  /* Cache drivers support */
  _getCacheDriver() {
    if (this._config.cache) {
      if (this._config.cache.type == IKGlobals.CacheDrivers.REDIS) return new IKCacheRedis(this._config.cache, this);
    } return null;
  }
}

==> ikapi-3.1.31.tgz: package/src/BaseEvent/IKProcess.js <==
//
import IKGlobals from '../IKGlobals';
import Utils  from "../API/IKUtils";
//Database
import IKDBDDB from "../Database/DDB/IKDB";
import IKDBPSQL from "../Database/PSQL/IKDB";
//Cache
import IKCacheRedis from '../Cache/Redis/IKRedis';
//Comps
import IKLogger from "../Logger/IKLogger";
import IKValidation from '../Validation/IKValidation';
import IKPublisher from '../Publisher/IKPublisher';
import IKExecutionTracker from '../Tracker/IKExecutionTracker';
//
export default class IKProcess {
  constructor(config, interval) {
    this._config = config;
    this.allowExecutionIdentification = false;
    this.interval = interval;
    this.logger = new IKLogger(config.logger, Utils.logLevel());
    this.publisher = new IKPublisher(config.publisher);
    this.validator = new IKValidation(config.validation);
    this.db = this._getDBDriver();
    this.cache = this._getCacheDriver();
    if (config.resourcesTracker) this.tracker = new IKExecutionTracker(config.resourcesTracker, null, this.db);
  }

  //Main interface
  async execute(executionFunc) {
    this.logger.debug("Starting main process code");
    //Tracker
    if (this.allowExecutionIdentification && this.tracker) this.tracker.resetExecutionTrace();
    //Connect DB
    if (this.db) await this.db.connect();
    //Program loop
    setInterval( async () => {
      await this._execute(executionFunc);
    }, this.interval);
    //Tracker
    if (this.allowExecutionIdentification && this.tracker) await this.tracker.trackExecAndDrain();
  }
  //Executions
  async _execute(executionFunc) {
    let executionFailed = true; //failled til we say no!
    //safe execution handler
    try { 
      //start DB transaction
      if (this.db) await this.db.beginTransaction();
      //Execute
      await executionFunc(this);
      //Commit DB
      if (this.db) await this.db.commit();
      //Tracker
      if (this.tracker) await this.tracker.quickDrain();
      //
      executionFailed = false;
    } catch (e) { /*EXECUTION FAIL*/
      this.logger.error('Exception when executing main request code. Rolling back DB!');
      this.logger.exception(e);
      //Rollback DB
      if (this.db) await this.db.rollback();
    } return executionFailed;
  }
  /* DB drivers support */
  _getDBDriver() {
    if (this._config.database) {
      if (this._config.database.type == IKGlobals.DBDrivers.PSQL) return new IKDBPSQL(this._config.database, this);
      else if (Object.keys(this._config.database).length > 0) return new IKDBDDB(this._config.database, this);
    } return null;
  }
  /* Cache drivers support */
  _getCacheDriver() {
    if (this._config.cache) {
      if (this._config.cache.type == IKGlobals.CacheDrivers.REDIS) return new IKCacheRedis(this._config.cache, this);
    } return null;
  }
}
